aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/GlobalAlias.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/GlobalAlias.h')
-rw-r--r--include/llvm/GlobalAlias.h15
1 files changed, 12 insertions, 3 deletions
diff --git a/include/llvm/GlobalAlias.h b/include/llvm/GlobalAlias.h
index b59537c..7c147eb 100644
--- a/include/llvm/GlobalAlias.h
+++ b/include/llvm/GlobalAlias.h
@@ -16,6 +16,7 @@
#define LLVM_GLOBAL_ALIAS_H
#include "llvm/GlobalValue.h"
+#include "llvm/OperandTraits.h"
namespace llvm {
@@ -42,17 +43,19 @@ class GlobalAlias : public GlobalValue {
GlobalAlias *getPrev() { return Prev; }
const GlobalAlias *getPrev() const { return Prev; }
- Use Aliasee;
public:
// allocate space for exactly zero operands
void *operator new(size_t s) {
- return User::operator new(s, 0);
+ return User::operator new(s, 1);
}
/// GlobalAlias ctor - If a parent module is specified, the alias is
/// automatically inserted into the end of the specified module's alias list.
GlobalAlias(const Type *Ty, LinkageTypes Linkage, const std::string &Name = "",
Constant* Aliasee = 0, Module *Parent = 0);
+ /// Provide fast operand accessors
+ DECLARE_TRANSPARENT_OPERAND_ACCESSORS(Value);
+
/// isDeclaration - Is this global variable lacking an initializer? If so,
/// the global variable is defined in some other translation unit, and is thus
/// only a declaration here.
@@ -95,6 +98,12 @@ public:
}
};
+template <>
+struct OperandTraits<GlobalAlias> : FixedNumOperandTraits<1> {
+};
+
+DEFINE_TRANSPARENT_OPERAND_ACCESSORS(GlobalAlias, Value)
+
} // End llvm namespace
#endif
@@ -42,17 +43,19 @@ class GlobalAlias : public GlobalValue {
public:
- // allocate space for exactly zero operands
+ // allocate space for exactly one operand
void *operator new(size_t s) {